(function() {
    'use strict';

    // Style and animate short reading time entries
    document.querySelectorAll('article.item.entry-item').forEach(entry => {
        const readingTimeElement = entry.querySelector('.item-meta-info-reading-time span');
        if (readingTimeElement && (readingTimeElement.textContent.includes('1 minute') || readingTimeElement.textContent.includes('2 minutes'))) {
            entry.style.backgroundColor = 'rgb(37, 44, 39)'; // Base dark muted greenish-gray
            entry.style.border = '1px solid rgb(79, 194, 20)'; // Subtle green border
            entry.style.borderRadius = '4px'; // Rounded corners
            entry.style.padding = '5px'; // Comfortable padding
            entry.style.transition = 'border-color 0.5s ease, box-shadow 0.5s ease'; // Smooth animation for border & shadow

            // Add hover effect for geeky animation
            entry.addEventListener('mouseover', () => {
                entry.style.borderColor = 'rgb(129, 255, 50)'; // Brighter green on hover
                entry.style.boxShadow = '0 0 10px rgba(129, 255, 50, 0.8)'; // Neon glow effect
            });

            entry.addEventListener('mouseout', () => {
                entry.style.borderColor = 'rgb(79, 194, 20)'; // Reset border color
                entry.style.boxShadow = 'none'; // Remove glow
            });
        }
    });

    // Add a filter for short reading times
    function addShortReadingTimeFilter() {
        const pageHeader = document.querySelector('.page-header nav ul');
        if (!pageHeader) return;

        const filterButton = document.createElement('button');
        filterButton.textContent = 'Filter: Short Reads';
        filterButton.style.marginLeft = '10px';
        filterButton.style.padding = '5px 10px';
        filterButton.style.border = '1px solid rgb(79, 194, 20)';
        filterButton.style.borderRadius = '5px';
        filterButton.style.backgroundColor = 'rgb(37, 44, 39)';
        filterButton.style.color = '#fff';
        filterButton.style.cursor = 'pointer';

        filterButton.onclick = () => {
            document.querySelectorAll('article.item.entry-item').forEach(entry => {
                const readingTimeElement = entry.querySelector('.item-meta-info-reading-time span');
                if (readingTimeElement && 
                    (readingTimeElement.textContent.includes('1 minute') || readingTimeElement.textContent.includes('2 minutes'))) {
                    entry.style.display = ''; // Show entry
                } else {
                    entry.style.display = 'none'; // Hide non-matching entries
                }
            });
        };

        pageHeader.appendChild(filterButton);
    }

    // Add the filter button after DOM is fully loaded
    document.addEventListener('DOMContentLoaded', addShortReadingTimeFilter);
})();